<?php
/**
 * VW Magazine functions and definitions
 *
 * @package VW Magazine
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

/* Theme Setup */
if ( ! function_exists( 'vw_magazine_setup' ) ) :
 
function vw_magazine_setup() {

	$GLOBALS['content_width'] = apply_filters( 'vw_magazine_content_width', 640 );
	
	load_theme_textdomain( 'vw-magazine', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('vw-magazine-homepage-thumb',240,145,true);
	
       register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'vw-magazine' ),
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );

	  /*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array('image','video','gallery','audio',) );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', vw_magazine_font_url() ) );
}


// Theme Activation Notice
	global $pagenow;

	if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
	add_action( 'admin_notices', 'vw_magazine_activation_notice' );
	}

	endif; // vw_charity_ngo_setup
	add_action( 'after_setup_theme', 'vw_magazine_setup' );

	// Notice after Theme Activation
	function vw_magazine_activation_notice() {
	echo '<div class="notice notice-success is-dismissible welcome-notice">';
	echo '<h3>'. esc_html__( 'Warm Greetings to you!!', 'vw-magazine' ) .'</h3>';
	echo '<p>'. esc_html__( 'Thank you for choosing VW Magazine Theme. Would like to have you on our Welcome page so that you can reap all the benefits of our VW Magazine Theme.', 'vw-magazine' ) .'</p>';
	echo '<p><a href="'. esc_url( admin_url( 'themes.php?page=vw_magazine_guide' ) ) .'" class="button button-primary">'. esc_html__( 'GET STARTED', 'vw-magazine' ) .'</a></p>';
	echo '</div>';
}

/* Theme Widgets Setup */
function vw_magazine_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'vw-magazine' ),
		'description'   => __( 'Appears on blog page sidebar', 'vw-magazine' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'vw-magazine' ),
		'description'   => __( 'Appears on page sidebar', 'vw-magazine' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 3', 'vw-magazine' ),
		'description'   => __( 'Appears on page sidebar', 'vw-magazine' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 1', 'vw-magazine' ),
		'description'   => __( 'Appears on footer 1', 'vw-magazine' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 2', 'vw-magazine' ),
		'description'   => __( 'Appears on footer 2', 'vw-magazine' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 3', 'vw-magazine' ),
		'description'   => __( 'Appears on footer 3', 'vw-magazine' ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 4', 'vw-magazine' ),
		'description'   => __( 'Appears on footer 4', 'vw-magazine'),
		'id'            => 'footer-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Social Icon', 'vw-magazine' ),
		'description'   => __( 'Appears on top bar', 'vw-magazine' ),
		'id'            => 'social-icon',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'vw_magazine_widgets_init' );

/* Theme Font URL */
function vw_magazine_font_url() {
	$font_url = '';
	$font_family = array();
	$font_family[] = 'PT Sans:300,400,600,700,800,900';
	$font_family[] = 'Montserrat:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Vollkorn:400,400i,600,600i,700,700i,900,900i';

	$query_args = array(
		'family'	=> urlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	return $font_url;
}

/* Theme enqueue scripts */
function vw_magazine_scripts() {
	wp_enqueue_style( 'vw-magazine-font', vw_magazine_font_url(), array() );
	wp_enqueue_style( 'bootstrap-style', get_template_directory_uri().'/css/bootstrap.css' );
	wp_enqueue_style( 'vw-magazine-basic-style', get_stylesheet_uri() );	
	wp_enqueue_style( 'effect', get_template_directory_uri().'/css/effect.css' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/css/fontawesome-all.css' );
	wp_enqueue_style( 'owl-carousel-css', get_template_directory_uri() . '/css/owl.carousel.css' );
	wp_enqueue_script( 'bootstrap-jquery', get_template_directory_uri() . '/js/bootstrap.js', array('jquery') ,'',true);	
	wp_enqueue_script( 'vw-magazine-custom-scripts-jquery', get_template_directory_uri() . '/js/custom.js', array('jquery') );	
	wp_enqueue_script( 'scrollslider-jquery', get_template_directory_uri() . '/js/jquery.scrollslider.js', array('jquery') );
	wp_enqueue_script( 'owl-carousel-jquery', get_template_directory_uri() . '/js/owl.carousel.js', array('jquery') );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	/* Enqueue the Dashicons script */
	wp_enqueue_style( 'dashicons' );
}
add_action( 'wp_enqueue_scripts', 'vw_magazine_scripts' );

function vw_magazine_ie_stylesheet(){
	wp_enqueue_style('vw-magazine-ie', get_template_directory_uri().'/css/ie.css');
	wp_style_add_data( 'vw-magazine-ie', 'conditional', 'IE' );
}
add_action('wp_enqueue_scripts','vw_magazine_ie_stylesheet');

/*radio button sanitization*/

function vw_magazine_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

define('VW_MAGAZINE_FREE_THEME_DOC','https://www.vwthemes.com/docs/free-vw-magazine/','vw-magazine');
define('VW_MAGAZINE_SUPPORT','https://wordpress.org/support/theme/vw-magazine/','vw-magazine');
define('VW_MAGAZINE_REVIEW','https://www.vwthemes.com/topic/reviews-and-testimonials/','vw-magazine');
define('VW_MAGAZINE_BUY_NOW','https://www.vwthemes.com/themes/premium-magazine-wordpress-theme/','vw-magazine');
define('VW_MAGAZINE_LIVE_DEMO','https://vwthemes.net/vw-magazine-pro/','vw-magazine');
define('VW_MAGAZINE_PRO_DOC','https://vwthemes.com/docs/vw-magazine-pro/','vw-magazine');
define('VW_MAGAZINE_FAQ','https://www.vwthemes.com/faqs/','vw-magazine');
define('VW_MAGAZINE_CHILD_THEME','https://developer.wordpress.org/themes/advanced-topics/child-themes/','vw-magazine');
define('VW_MAGAZINE_CONTACT','https://www.vwthemes.com/contact/','vw-magazine');
define('VW_MAGAZINE_DEMO_DATA','https://vwthemes.net/docs/vw-magazine-demo.xml.zip','vw-magazine');

/* Excerpt Limit Begin */
function vw_magazine_education_string_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit)
	array_pop($words);
	return implode(' ', $words);
}

define('VW_MAGAZINE_CREDIT','https://www.vwthemes.com','vw-magazine');

if ( ! function_exists( 'vw_magazine_credit' ) ) {
	function vw_magazine_credit(){
		echo "<a href=".esc_url(VW_MAGAZINE_CREDIT)." target='_blank'>".esc_html__('VWThemes','vw-magazine')."</a>";
	}
}

/* Implement the Custom Header feature. */
require get_template_directory() . '/inc/custom-header.php';

/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';

/* Customizer additions. */
require get_template_directory() . '/inc/customizer.php';

/* Social Custom Widgets */
require get_template_directory() . '/inc/custom-widgets/social-profile.php';

/* get-started file. */
require get_template_directory() . '/inc/get-started/get-started.php';