<?php
/**
 * VW Magazine Theme Customizer
 *
 * @package VW Magazine
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_magazine_customize_register( $wp_customize ) {

	//add home page setting pannel
	$wp_customize->add_panel( 'vw_magazine_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'vw-magazine' ),
	    'description' => __( 'Description of what this panel does.', 'vw-magazine' ),
	) );

	$wp_customize->add_section( 'vw_magazine_left_right', array(
    	'title'      => __( 'General Settings', 'vw-magazine' ),
		'priority'   => 30,
		'panel' => 'vw_magazine_panel_id'
	) );

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_magazine_theme_options',array(
        'default' => __('Right Sidebar','vw-magazine'),
        'sanitize_callback' => 'vw_magazine_sanitize_choices'	        
	));
	$wp_customize->add_control('vw_magazine_theme_options',array(
        'type' => 'radio',
        'label' => __('Do you want this section','vw-magazine'),
        'section' => 'vw_magazine_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-magazine'),
            'Right Sidebar' => __('Right Sidebar','vw-magazine'),
            'One Column' => __('One Column','vw-magazine'),
            'Three Columns' => __('Three Columns','vw-magazine'),
            'Four Columns' => __('Four Columns','vw-magazine'),
            'Grid Layout' => __('Grid Layout','vw-magazine')
        ),
	)   );
    
	//Topbar section
	$wp_customize->add_section('vw_magazine_topbar',array(
		'title'	=> __('Topbar Section','vw-magazine'),
		'description'	=> __('Add TopBar Content here','vw-magazine'),
		'priority'	=> null,
		'panel' => 'vw_magazine_panel_id',
	));
	
	$wp_customize->add_setting('vw_magazine_contact',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_magazine_contact',array(
		'label'	=> __('Add Contact Details','vw-magazine'),
		'section'	=> 'vw_magazine_topbar',
		'setting'	=> 'vw_magazine_contact',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_email',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_magazine_email',array(
		'label'	=> __('Add Email Address','vw-magazine'),
		'section'	=> 'vw_magazine_topbar',
		'setting'	=> 'vw_magazine_email',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_header_top_headline',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_magazine_header_top_headline',array(
		'label'	=> __('Add Top Title','vw-magazine'),
		'section'	=> 'vw_magazine_topbar',
		'setting'	=> 'vw_magazine_header_top_headline',
		'type'		=> 'text'
	));

	//Header Section
	$wp_customize->add_section('vw_magazine_top_header',array(
		'title'	=> __('Header Section','vw-magazine'),
		'description'	=> __('Add Header content below.','vw-magazine'),
		'panel' => 'vw_magazine_panel_id',
	));

	$wp_customize->add_setting('vw_magazine_header_weather_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_magazine_header_weather_text',array(
		'label'	=> __('Add City Name','vw-magazine'),
		'section'	=> 'vw_magazine_top_header',
		'setting'	=> 'vw_magazine_header_weather_text',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_header_percent',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_magazine_header_percent',array(
		'label'	=> __('Add Weather Percnt','vw-magazine'),
		'section'	=> 'vw_magazine_top_header',
		'setting'	=> 'vw_magazine_header_percent',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_header_date',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_magazine_header_date',array(
		'label'	=> __('Add Day, Date','vw-magazine'),
		'section'	=> 'vw_magazine_top_header',
		'setting'	=> 'vw_magazine_header_date',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_magazine_header_timing',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_magazine_header_timing',array(
		'label'	=> __('Add Time','vw-magazine'),
		'section'	=> 'vw_magazine_top_header',
		'setting'	=> 'vw_magazine_header_timing',
		'type'		=> 'text'
	));

	$post_list = get_posts();
	$i = 0;
	foreach($post_list as $post){
		$posts[$post->post_title] = $post->post_title;
	}

	$wp_customize->add_setting('vw_magazine_top_banner_post',array(
		'sanitize_callback' => 'vw_magazine_sanitize_choices',
	));
	$wp_customize->add_control('vw_magazine_top_banner_post',array(
		'type'    => 'select',
		'choices' => $posts,
		'label' => __('Select post','vw-magazine'),
		'section' => 'vw_magazine_top_header',
	));

	$wp_customize->add_setting('vw_magazine_top_banner_button',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_magazine_top_banner_button',array(
		'label'	=> __('Button text','vw-magazine'),
		'section'	=> 'vw_magazine_top_header',
		'setting'	=> 'vw_magazine_top_banner_button',
		'type'		=> 'text'
	));

	//Post Carousel
	$wp_customize->add_section('vw_magazine_post_carousel',array(
		'title'	=> __('Post Carousel','vw-magazine'),
		'description'	=> __('Select the post category and show your post','vw-magazine'),
		'priority'	=> null,
		'panel' => 'vw_magazine_panel_id',
	));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cats[$category->slug] = $category->name;
	}
	$wp_customize->add_setting('vw_magazine_post_carousel_category',array(
		'sanitize_callback' => 'vw_magazine_sanitize_choices',
	));
	$wp_customize->add_control('vw_magazine_post_carousel_category',array(
		'type'    => 'select',
		'choices' => $cats,
		'label' => __('Select category from here','vw-magazine'),
		'section' => 'vw_magazine_post_carousel',
	));

	//Post Section Two
	$wp_customize->add_section('vw_magazine_latest_post_section',array(
		'title'	=> __('Latest Post','vw-magazine'),
		'description'	=> __('Select the post category and show your post','vw-magazine'),
		'priority'	=> null,
		'panel' => 'vw_magazine_panel_id',
	));
	$wp_customize->add_setting('vw_magazine_latest_post_title',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field',
	));
	$wp_customize->add_control('vw_magazine_latest_post_title',array(
		'label'	=> __('Section Title','vw-magazine'),
		'section'	=> 'vw_magazine_latest_post_section',
		'type'	=> 'text'
	));
	$categories = get_categories();
	$cats = array();
	$i = 0;
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cats[$category->slug] = $category->name;
	}
	$wp_customize->add_setting('vw_magazine_latest_post_category',array(
		'sanitize_callback' => 'vw_magazine_sanitize_choices',
	));
	$wp_customize->add_control('vw_magazine_latest_post_category',array(
		'type'    => 'select',
		'choices' => $cats,
		'label' => __('Select category from here','vw-magazine'),
		'section' => 'vw_magazine_latest_post_section',
	));

	//Footer Text
	$wp_customize->add_section('vw_magazine_footer',array(
		'title'	=> __('Footer','vw-magazine'),
		'description'=> __('This section will appear in the footer','vw-magazine'),
		'panel' => 'vw_magazine_panel_id',
	));	
	
	$wp_customize->add_setting('vw_magazine_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_magazine_footer_text',array(
		'label'	=> __('Copyright Text','vw-magazine'),
		'section'=> 'vw_magazine_footer',
		'setting'=> 'vw_magazine_footer_text',
		'type'=> 'text'
	));	
}

add_action( 'customize_register', 'vw_magazine_customize_register' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Magazine_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Magazine_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new VW_Magazine_Customize_Section_Pro(
				$manager,
				'example_1',
				array(
					'priority'   => 9,
					'title'    => esc_html__( 'VW Magazine Pro', 'vw-magazine' ),
					'pro_text' => esc_html__( 'Upgrade Pro', 'vw-magazine' ),
					'pro_url'  => esc_url('https://www.vwthemes.com/themes/premium-magazine-wordpress-theme/')
				)
			)
		);

		$manager->add_section(
			new VW_Magazine_Customize_Section_Pro(
				$manager,
				'example_2',
				array(
					'priority'   => 9,
					'title'    => esc_html__( 'Documentation', 'vw-magazine' ),
					'pro_text' => esc_html__( 'Docs', 'vw-magazine' ),
					'pro_url'  => admin_url('themes.php?page=vw_magazine_guide')
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-magazine-customize-controls', trailingslashit( get_template_directory_uri() ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-magazine-customize-controls', trailingslashit( get_template_directory_uri() ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Magazine_Customize::get_instance();